pub struct AccountId(/* private fields */);Expand description
Represents a valid account ID.
Implementations
Sourceimpl AccountId
impl AccountId
Sourcepub fn new_checked<T: AsRef<str>>(value: T) -> CorrectnessResult<Self>
pub fn new_checked<T: AsRef<str>>(value: T) -> CorrectnessResult<Self>
Creates a new AccountId instance with correctness checking.
Must be correctly formatted with two valid strings either side of a hyphen ‘-’.
It is expected an account ID is the name of the issuer with an account number separated by a hyphen.
Errors
Returns an error if:
valueis not a valid ASCII string.valuedoes not contain a hyphen ‘-’ separator.- Either the issuer or account part (before/after the hyphen) is empty.
Notes
PyO3 requires a Result type for proper error handling and stacktrace printing in Python.
Sourcepub fn get_issuer(&self) -> Venue
pub fn get_issuer(&self) -> Venue
Returns the account issuer for this identifier.
Panics
Panics if the internal ID does not contain a hyphen separator.
Sourcepub fn get_issuers_id(&self) -> &str
pub fn get_issuers_id(&self) -> &str
Returns the account ID assigned by the issuer.
Panics
Panics if the internal ID does not contain a hyphen separator.